@@ -66,6 +66,7 @@ private slots:
     void testGeneratorPreferences();
     void testSelectText();
     void testClickInternalLink();
+    void testScrollBarAndMouseWheel();
     void testOpenUrlArguments();
     void test388288();
     void testSaveAs();
@@ -95,6 +96,7 @@ private slots:
     void testAdditionalActionTriggers();
     void testTypewriterAnnotTool();
     void testJumpToPage();
+    void testOpenAtPage();
     void testForwardBackwardNavigation();
     void testTabletProximityBehavior();
     void testOpenPrintPreview();
@@ -312,6 +314,49 @@ void PartTest::testClickInternalLink()
     QTest::mouseMove(part.m_pageView->viewport(), QPoint(width * 0.17, height * 0.05));
     QTest::mouseClick(part.m_pageView->viewport(), Qt::LeftButton, Qt::NoModifier, QPoint(width * 0.17, height * 0.05));
     QTRY_COMPARE(part.m_document->currentPage(), 1u);
+
+    // make sure cursor goes back to being an open hand again.  Bug 421437
+    QTRY_COMPARE_WITH_TIMEOUT(part.m_pageView->cursor().shape(), Qt::OpenHandCursor, 1000);
+}
+
+// Test for bug 421159, which is: When scrolling down with the scroll bar
+// followed by scrolling down with the mouse wheel, the mouse wheel scrolling
+// will make the viewport jump back to the first page.
+void PartTest::testScrollBarAndMouseWheel()
+{
+    QVariantList dummyArgs;
+    Okular::Part part(nullptr, nullptr, dummyArgs);
+    QVERIFY(openDocument(&part, QStringLiteral(KDESRCDIR "data/simple-multipage.pdf")));
+    part.widget()->show();
+    QVERIFY(QTest::qWaitForWindowExposed(part.widget()));
+
+    part.m_document->setViewportPage(0);
+
+    // wait for pixmap
+    QTRY_VERIFY(part.m_document->page(0)->hasPixmap(part.m_pageView));
+
+    // Make sure we are on the first page
+    QCOMPARE(part.m_document->currentPage(), 0u);
+
+    // Two clicks on the vertical scrollbar
+    auto scrollBar = part.m_pageView->verticalScrollBar();
+
+    QTest::mouseClick(scrollBar, Qt::LeftButton);
+    QTest::qWait(QApplication::doubleClickInterval() * 2); // Wait a tiny bit
+    QTest::mouseClick(scrollBar, Qt::LeftButton);
+
+    // We have scrolled enough to be on the second page now
+    QCOMPARE(part.m_document->currentPage(), 1u);
+
+    // Scroll further down using the mouse wheel
+    auto wheelDown = new QWheelEvent({}, {}, {}, {0, -150}, Qt::NoButton, Qt::NoModifier, Qt::NoScrollPhase, false);
+    QCoreApplication::postEvent(part.m_pageView->viewport(), wheelDown);
+
+    // Wait a little for the scrolling to actually happen.
+    // We should still be on the second page after that.
+    QTest::qWait(1000);
+
+    QCOMPARE(part.m_document->currentPage(), 1u);
 }
 
 // cursor switches to Hand when hovering over link in TextSelect mode.
@@ -1386,10 +1431,6 @@ void PartTest::test388288()
 
 void PartTest::testCheckBoxReadOnly()
 {
-#ifndef HAVE_POPPLER_0_64
-    return;
-#endif
-
     const QString testFile = QStringLiteral(KDESRCDIR "data/checkbox_ro.pdf");
     Okular::Part part(nullptr, nullptr, QVariantList());
     part.openDocument(testFile);
@@ -1616,9 +1657,6 @@ static void verifyTargetStates(const QString &triggerName, const QMap<QString, O
 
 void PartTest::testAdditionalActionTriggers()
 {
-#ifndef HAVE_POPPLER_0_65
-    return;
-#endif
     const QString testFile = QStringLiteral(KDESRCDIR "data/additionalFormActions.pdf");
     Okular::Part part(nullptr, nullptr, QVariantList());
     part.openDocument(testFile);
@@ -1794,6 +1832,26 @@ void PartTest::testJumpToPage()
     QCOMPARE(part.m_pageView->verticalScrollBar()->value(), pageWithSpaceTop - 4);
 }
 
+void PartTest::testOpenAtPage()
+{
+    const QString testFile = QStringLiteral(KDESRCDIR "data/simple-multipage.pdf");
+    QUrl url = QUrl::fromLocalFile(testFile);
+    Okular::Part part(nullptr, nullptr, QVariantList());
+
+    const uint targetPageNumA = 25;
+    const uint expectedPageA = targetPageNumA - 1;
+    url.setFragment(QString::number(targetPageNumA));
+    part.openUrl(url);
+    QCOMPARE(part.m_document->currentPage(), expectedPageA);
+
+    // 'page=<pagenum>' param as specified in RFC 3778
+    const uint targetPageNumB = 15;
+    const uint expectedPageB = targetPageNumB - 1;
+    url.setFragment("page=" + QString::number(targetPageNumB));
+    part.openUrl(url);
+    QCOMPARE(part.m_document->currentPage(), expectedPageB);
+}
+
 void PartTest::testForwardBackwardNavigation()
 {
     const QString testFile = QStringLiteral(KDESRCDIR "data/simple-multipage.pdf");
