@@ -45,7 +45,6 @@
 #include <core/movie.h>
 #include <core/page.h>
 #include <core/pagetransition.h>
-#include <core/printoptionswidget.h>
 #include <core/sound.h>
 #include <core/sourcereference.h>
 #include <core/textpage.h>
@@ -54,12 +53,8 @@
 #include "pdfsettings.h"
 #include "ui_pdfsettingswidget.h"
 
-#include <config-okular-poppler.h>
-
 #include <poppler-media.h>
-#ifdef HAVE_POPPLER_0_73
 #include <poppler-version.h>
-#endif
 
 #include "annots.h"
 #include "debug_pdf.h"
@@ -72,11 +67,7 @@ Q_DECLARE_METATYPE(const Poppler::LinkMovie *)
 Q_DECLARE_METATYPE(const Poppler::LinkRendition *)
 Q_DECLARE_METATYPE(const Poppler::LinkOCGState *)
 
-#ifdef HAVE_POPPLER_0_73
 #define POPPLER_VERSION_MACRO ((POPPLER_VERSION_MAJOR << 16) | (POPPLER_VERSION_MINOR << 8) | (POPPLER_VERSION_MICRO))
-#else
-#define POPPLER_VERSION_MACRO 0
-#endif
 
 static const int defaultPageWidth = 595;
 static const int defaultPageHeight = 842;
@@ -247,7 +238,7 @@ Okular::Movie *createMovieFromPopplerScreen(const Poppler::LinkRendition *popple
 
 QPair<Okular::Movie *, Okular::EmbeddedFile *> createMovieFromPopplerRichMedia(const Poppler::RichMediaAnnotation *popplerRichMedia)
 {
-    const QPair<Okular::Movie *, Okular::EmbeddedFile *> emptyResult(0, 0);
+    const QPair<Okular::Movie *, Okular::EmbeddedFile *> emptyResult(nullptr, nullptr);
 
     /**
      * To convert a Flash/Video based RichMedia annotation to a movie, we search for the first
@@ -474,7 +465,6 @@ Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
         link = movieAction;
     } break;
 
-#ifdef HAVE_POPPLER_0_64
     case Poppler::Link::Hide: {
         const Poppler::LinkHide *l = static_cast<const Poppler::LinkHide *>(popplerLink);
         QStringList scripts;
@@ -484,7 +474,6 @@ Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
         }
         link = new Okular::ScriptAction(Okular::JavaScript, scripts.join(QLatin1Char('\n')));
     } break;
-#endif
 
     case Poppler::Link::OCGState:
         link = new Okular::BackendOpaqueAction();
@@ -493,7 +482,6 @@ Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
         break;
     }
 
-#ifdef HAVE_POPPLER_0_64
     if (link) {
         QVector<Okular::Action *> nextActions;
         const QVector<Poppler::Link *> nextLinks = popplerLink->nextLinks();
@@ -502,7 +490,6 @@ Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
         }
         link->setNextActions(nextActions);
     }
-#endif
 
     if (deletePopplerLink)
         delete popplerLink;
@@ -571,9 +558,7 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
     setFeature(ReadRawData);
     setFeature(TiledRendering);
     setFeature(SwapBackingFile);
-#ifdef HAVE_POPPLER_0_63
     setFeature(SupportsCancelling);
-#endif
 
     // You only need to do it once not for each of the documents but it is cheap enough
     // so doing it all the time won't hurt either
@@ -860,13 +845,13 @@ const Okular::DocumentSynopsis *PDFGenerator::generateDocumentSynopsis()
         return nullptr;
 
     userMutex()->lock();
-    QDomDocument *toc = pdfdoc->toc();
+    const QVector<Poppler::OutlineItem> outline = pdfdoc->outline();
     userMutex()->unlock();
-    if (!toc)
+
+    if (outline.isEmpty())
         return nullptr;
 
-    addSynopsisChildren(toc, &docSyn);
-    delete toc;
+    addSynopsisChildren(outline, &docSyn);
 
     docSynopsisDirty = false;
     return &docSyn;
@@ -947,9 +932,7 @@ Okular::FontInfo::List PDFGenerator::fontsForPage(int page)
     for (const Poppler::FontInfo &font : qAsConst(fonts)) {
         Okular::FontInfo of;
         of.setName(font.name());
-#ifdef HAVE_POPPLER_0_80
         of.setSubstituteName(font.substituteName());
-#endif
         of.setType(convertPopplerFontInfoTypeToOkularFontInfoType(font.type()));
         of.setEmbedType(embedTypeForPopplerFontInfo(font));
         of.setFile(font.file());
@@ -1057,13 +1040,11 @@ static void partialUpdateCallback(const QImage &image, const QVariant &vPayload)
     // clang-format on
 }
 
-#ifdef HAVE_POPPLER_0_63
 static bool shouldAbortRenderCallback(const QVariant &vPayload)
 {
     auto payload = vPayload.value<RenderImagePayload *>();
     return payload->request->shouldAbortRender();
 }
-#endif
 
 QImage PDFGenerator::image(Okular::PixmapRequest *request)
 {
@@ -1099,7 +1080,6 @@ QImage PDFGenerator::image(Okular::PixmapRequest *request)
     // 2. Take data from outputdev and attach it to the Page
     QImage img;
     if (p) {
-#ifdef HAVE_POPPLER_0_63
         if (request->isTile()) {
             const QRect rect = request->normalizedRect().geometry(request->width(), request->height());
             if (request->partialUpdatesWanted()) {
@@ -1119,24 +1099,6 @@ QImage PDFGenerator::image(Okular::PixmapRequest *request)
                 img = p->renderToImage(fakeDpiX, fakeDpiY, -1, -1, -1, -1, Poppler::Page::Rotate0, nullptr, nullptr, shouldAbortRenderCallback, QVariant::fromValue(&payload));
             }
         }
-#else
-        if (request->isTile()) {
-            const QRect rect = request->normalizedRect().geometry(request->width(), request->height());
-            if (request->partialUpdatesWanted()) {
-                RenderImagePayload payload(this, request);
-                img = p->renderToImage(fakeDpiX, fakeDpiY, rect.x(), rect.y(), rect.width(), rect.height(), Poppler::Page::Rotate0, partialUpdateCallback, shouldDoPartialUpdateCallback, QVariant::fromValue(&payload));
-            } else {
-                img = p->renderToImage(fakeDpiX, fakeDpiY, rect.x(), rect.y(), rect.width(), rect.height(), Poppler::Page::Rotate0);
-            }
-        } else {
-            if (request->partialUpdatesWanted()) {
-                RenderImagePayload payload(this, request);
-                img = p->renderToImage(fakeDpiX, fakeDpiY, -1, -1, -1, -1, Poppler::Page::Rotate0, partialUpdateCallback, shouldDoPartialUpdateCallback, QVariant::fromValue(&payload));
-            } else {
-                img = p->renderToImage(fakeDpiX, fakeDpiY, -1, -1, -1, -1, Poppler::Page::Rotate0);
-            }
-        }
-#endif
     } else {
         img = QImage(request->width(), request->height(), QImage::Format_Mono);
         img.fill(Qt::white);
@@ -1222,7 +1184,6 @@ void PDFGenerator::resolveMediaLinkReferences(Okular::Page *page)
     }
 }
 
-#ifdef HAVE_POPPLER_0_63
 struct TextExtractionPayload {
     TextExtractionPayload(Okular::TextRequest *r)
         : request(r)
@@ -1238,7 +1199,6 @@ static bool shouldAbortTextExtractionCallback(const QVariant &vPayload)
     auto payload = vPayload.value<TextExtractionPayload *>();
     return payload->request->shouldAbortExtraction();
 }
-#endif
 
 Okular::TextPage *PDFGenerator::textPage(Okular::TextRequest *request)
 {
@@ -1252,12 +1212,8 @@ Okular::TextPage *PDFGenerator::textPage(Okular::TextRequest *request)
     userMutex()->lock();
     Poppler::Page *pp = pdfdoc->page(page->number());
     if (pp) {
-#ifdef HAVE_POPPLER_0_63
         TextExtractionPayload payload(request);
         textList = pp->textList(Poppler::Page::Rotate0, shouldAbortTextExtractionCallback, QVariant::fromValue(&payload));
-#else
-        textList = pp->textList();
-#endif
         const QSizeF s = pp->pageSizeF();
         pageWidth = s.width();
         pageHeight = s.height();
@@ -1475,24 +1431,11 @@ QVariant PDFGenerator::metaData(const QString &key, const QVariant &option) cons
         QMutexLocker ml(userMutex());
         return QVariant::fromValue<QVector<int>>(pdfdoc->formCalculateOrder());
     } else if (key == QLatin1String("GeneratorExtraDescription")) {
-#ifdef HAVE_POPPLER_0_73
         if (Poppler::Version::string() == QStringLiteral(POPPLER_VERSION)) {
             return i18n("Using Poppler %1", Poppler::Version::string());
         } else {
             return i18n("Using Poppler %1\n\nBuilt against Poppler %2", Poppler::Version::string(), POPPLER_VERSION);
         }
-#endif
-    } else if (key == QLatin1String("IsDigitallySigned")) {
-        const Okular::Document *doc = document();
-        uint numPages = doc->pages();
-        for (uint i = 0; i < numPages; i++) {
-            const QLinkedList<Okular::FormField *> formFields = doc->page(i)->formFields();
-            for (const Okular::FormField *f : formFields) {
-                if (f->type() == Okular::FormField::FormSignature)
-                    return true;
-            }
-        }
-        return false;
     }
     return QVariant();
 }
@@ -1653,36 +1596,29 @@ Okular::TextPage *PDFGenerator::abstractTextPage(const QList<Poppler::TextBox *>
     return ktp;
 }
 
-void PDFGenerator::addSynopsisChildren(QDomNode *parent, QDomNode *parentDestination)
+void PDFGenerator::addSynopsisChildren(const QVector<Poppler::OutlineItem> &outlineItems, QDomNode *parentDestination)
 {
-    // keep track of the current listViewItem
-    QDomNode n = parent->firstChild();
-    while (!n.isNull()) {
-        // convert the node to an element (sure it is)
-        QDomElement e = n.toElement();
-
-        // The name is the same
-        QDomElement item = docSyn.createElement(e.tagName());
+    for (const Poppler::OutlineItem &outlineItem : outlineItems) {
+        QDomElement item = docSyn.createElement(outlineItem.name());
         parentDestination->appendChild(item);
 
-        if (!e.attribute(QStringLiteral("ExternalFileName")).isNull())
-            item.setAttribute(QStringLiteral("ExternalFileName"), e.attribute(QStringLiteral("ExternalFileName")));
-        if (!e.attribute(QStringLiteral("DestinationName")).isNull())
-            item.setAttribute(QStringLiteral("ViewportName"), e.attribute(QStringLiteral("DestinationName")));
-        if (!e.attribute(QStringLiteral("Destination")).isNull()) {
-            Okular::DocumentViewport vp;
-            fillViewportFromLinkDestination(vp, Poppler::LinkDestination(e.attribute(QStringLiteral("Destination"))));
-            item.setAttribute(QStringLiteral("Viewport"), vp.toString());
+        item.setAttribute(QStringLiteral("ExternalFileName"), outlineItem.externalFileName());
+        const QSharedPointer<const Poppler::LinkDestination> outlineDestination = outlineItem.destination();
+        if (outlineDestination) {
+            const QString destinationName = outlineDestination->destinationName();
+            if (!destinationName.isEmpty()) {
+                item.setAttribute(QStringLiteral("ViewportName"), destinationName);
+            } else {
+                Okular::DocumentViewport vp;
+                fillViewportFromLinkDestination(vp, *outlineDestination);
+                item.setAttribute(QStringLiteral("Viewport"), vp.toString());
+            }
         }
-        if (!e.attribute(QStringLiteral("Open")).isNull())
-            item.setAttribute(QStringLiteral("Open"), e.attribute(QStringLiteral("Open")));
-        if (!e.attribute(QStringLiteral("DestinationURI")).isNull())
-            item.setAttribute(QStringLiteral("URL"), e.attribute(QStringLiteral("DestinationURI")));
+        item.setAttribute(QStringLiteral("Open"), outlineItem.isOpen());
+        item.setAttribute(QStringLiteral("URL"), outlineItem.uri());
 
-        // descend recursively and advance to the next node
-        if (e.hasChildNodes())
-            addSynopsisChildren(&n, &item);
-        n = n.nextSibling();
+        if (outlineItem.hasChildren())
+            addSynopsisChildren(outlineItem.children(), &item);
     }
 }
 
@@ -1696,7 +1632,7 @@ void PDFGenerator::addAnnotations(Poppler::Page *popplerPage, Okular::Page *page
 
     for (Poppler::Annotation *a : popplerAnnotations) {
         bool doDelete = true;
-        Okular::Annotation *newann = createAnnotationFromPopplerAnnotation(a, &doDelete);
+        Okular::Annotation *newann = createAnnotationFromPopplerAnnotation(a, *popplerPage, &doDelete);
         if (newann) {
             page->addAnnotation(newann);
 
