@@ -43,8 +43,6 @@ public:
     explicit AnnotationActionHandlerPrivate(AnnotationActionHandler *qq)
         : q(qq)
         , annotator(nullptr)
-        , textTools(nullptr)
-        , textQuickTools(nullptr)
         , agTools(nullptr)
         , agLastAction(nullptr)
         , aQuickTools(nullptr)
@@ -83,21 +81,18 @@ public:
      * matches a default stamp, any existing stamp annotation action is removed.
      */
     void maybeUpdateCustomStampAction(const QString &stampIconName);
-    void parseTool(int toolID);
+    void parseTool(int toolId);
 
     void updateConfigActions(const QString &annotType = QLatin1String(""));
     void populateQuickAnnotations();
     KSelectAction *colorPickerAction(AnnotationColor colorType);
 
-    const QIcon colorIcon(const QColor &color);
     const QIcon widthIcon(double width);
-    const QIcon colorPickerIcon(const QString &iconName, const QColor &color);
-    const QIcon opacityIcon(double opacity);
     const QIcon stampIcon(const QString &stampIconName);
 
-    void selectTool(int toolID);
+    void selectTool(int toolId);
     void slotStampToolSelected(const QString &stamp);
-    void slotQuickToolSelected(int favToolID);
+    void slotQuickToolSelected(int favToolId);
     void slotSetColor(AnnotationColor colorType, const QColor &color = QColor());
     void slotSelectAnnotationFont();
     void slotToolBarVisibilityChanged(bool checked);
@@ -106,8 +101,8 @@ public:
 
     PageViewAnnotator *annotator;
 
-    QList<QAction *> *textTools;
-    QList<QAction *> *textQuickTools;
+    QList<QAction *> textTools;
+    QList<QAction *> textQuickTools;
     QActionGroup *agTools;
     QAction *agLastAction;
 
@@ -139,22 +134,22 @@ public:
     bool textToolsEnabled;
 };
 
-const QList<QPair<KLocalizedString, QColor>> AnnotationActionHandlerPrivate::defaultColors = {{ki18n("Red"), Qt::red},
-                                                                                              {ki18n("Orange"), QColor(255, 85, 0)},
-                                                                                              {ki18n("Yellow"), Qt::yellow},
-                                                                                              {ki18n("Green"), Qt::green},
-                                                                                              {ki18n("Cyan"), Qt::cyan},
-                                                                                              {ki18n("Blue"), Qt::blue},
-                                                                                              {ki18n("Magenta"), Qt::magenta},
-                                                                                              {ki18n("White"), Qt::white},
-                                                                                              {ki18n("Gray"), Qt::gray},
-                                                                                              {ki18n("Black"), Qt::black}
+const QList<QPair<KLocalizedString, QColor>> AnnotationActionHandlerPrivate::defaultColors = {{ki18nc("@item:inlistbox Color name", "Red"), Qt::red},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Orange"), QColor(255, 85, 0)},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Yellow"), Qt::yellow},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Green"), Qt::green},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Cyan"), Qt::cyan},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Blue"), Qt::blue},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Magenta"), Qt::magenta},
+                                                                                              {ki18nc("@item:inlistbox Color name", "White"), Qt::white},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Gray"), Qt::gray},
+                                                                                              {ki18nc("@item:inlistbox Color name", "Black"), Qt::black}
 
 };
 
 const QList<double> AnnotationActionHandlerPrivate::widthStandardValues = {1, 1.5, 2, 2.5, 3, 3.5, 4, 4.5, 5};
 
-const QList<double> AnnotationActionHandlerPrivate::opacityStandardValues = {10, 20, 30, 40, 50, 60, 70, 80, 90, 100};
+const QList<double> AnnotationActionHandlerPrivate::opacityStandardValues = {0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0};
 
 QAction *AnnotationActionHandlerPrivate::selectActionItem(KSelectAction *aList, QAction *aCustomCurrent, double value, const QList<double> &defaultValues, const QIcon &icon, const QString &label)
 {
@@ -199,14 +194,14 @@ void AnnotationActionHandlerPrivate::maybeUpdateCustomStampAction(const QString
     }
 }
 
-void AnnotationActionHandlerPrivate::parseTool(int toolID)
+void AnnotationActionHandlerPrivate::parseTool(int toolId)
 {
-    if (toolID == -1) {
+    if (toolId == -1) {
         updateConfigActions();
         return;
     }
 
-    QDomElement toolElement = annotator->builtinTool(toolID);
+    QDomElement toolElement = annotator->builtinTool(toolId);
     const QString annotType = toolElement.attribute(QStringLiteral("type"));
     QDomElement engineElement = toolElement.firstChildElement(QStringLiteral("engine"));
     QDomElement annElement = engineElement.firstChildElement(QStringLiteral("annotation"));
@@ -241,8 +236,8 @@ void AnnotationActionHandlerPrivate::parseTool(int toolID)
 
     // if the opacity value is not a default one, insert a new action in the opacity list
     if (annElement.hasAttribute(QStringLiteral("opacity"))) {
-        double opacity = 100 * annElement.attribute(QStringLiteral("opacity")).toDouble();
-        aCustomOpacity = selectActionItem(aOpacity, aCustomOpacity, opacity, opacityStandardValues, opacityIcon(opacity), i18nc("@item:inlistbox", "%1\%", opacity));
+        double opacity = annElement.attribute(QStringLiteral("opacity")).toDouble();
+        aCustomOpacity = selectActionItem(aOpacity, aCustomOpacity, opacity, opacityStandardValues, GuiUtils::createOpacityIcon(opacity), i18nc("@item:inlistbox", "%1\%", opacity * 100));
     } else {
         aOpacity->setCurrentItem(opacityStandardValues.size() - 1); // 100 %
     }
@@ -269,11 +264,11 @@ void AnnotationActionHandlerPrivate::updateConfigActions(const QString &annotTyp
     const bool isStamp = annotType == QStringLiteral("stamp");
 
     if (isTypewriter) {
-        aColor->setIcon(colorPickerIcon(QStringLiteral("format-text-color"), currentColor));
+        aColor->setIcon(GuiUtils::createColorIcon({currentColor}, QIcon::fromTheme(QStringLiteral("format-text-color"))));
     } else {
-        aColor->setIcon(colorPickerIcon(QStringLiteral("format-stroke-color"), currentColor));
+        aColor->setIcon(GuiUtils::createColorIcon({currentColor}, QIcon::fromTheme(QStringLiteral("format-stroke-color"))));
     }
-    aInnerColor->setIcon(colorPickerIcon(QStringLiteral("format-fill-color"), currentInnerColor));
+    aInnerColor->setIcon(GuiUtils::createColorIcon({currentInnerColor}, QIcon::fromTheme(QStringLiteral("format-fill-color"))));
 
     aAddToQuickTools->setEnabled(isAnnotationSelected);
     aWidth->setEnabled(isLine || isShape);
@@ -344,7 +339,7 @@ void AnnotationActionHandlerPrivate::populateQuickAnnotations()
 
     const QList<int> numberKeys = {Qt::Key_1, Qt::Key_2, Qt::Key_3, Qt::Key_4, Qt::Key_5, Qt::Key_6, Qt::Key_7, Qt::Key_8, Qt::Key_9, Qt::Key_0};
 
-    textQuickTools->clear();
+    textQuickTools.clear();
     aQuickTools->removeAllActions();
 
     int favToolId = 1;
@@ -364,7 +359,7 @@ void AnnotationActionHandlerPrivate::populateQuickAnnotations()
 
         QDomElement engineElement = favToolElement.firstChildElement(QStringLiteral("engine"));
         if (engineElement.attribute(QStringLiteral("type")) == QStringLiteral("TextSelector")) {
-            textQuickTools->append(annFav);
+            textQuickTools.append(annFav);
             annFav->setEnabled(textToolsEnabled);
         }
 
@@ -387,13 +382,13 @@ KSelectAction *AnnotationActionHandlerPrivate::colorPickerAction(AnnotationColor
     QString aText(i18nc("@action:intoolbar Current annotation config option", "Color"));
     if (colorType == AnnotationColor::InnerColor) {
         aText = i18nc("@action:intoolbar Current annotation config option", "Fill Color");
-        colorList.append(QPair<KLocalizedString, Qt::GlobalColor>(ki18n("Transparent"), Qt::transparent));
+        colorList.append(QPair<KLocalizedString, Qt::GlobalColor>(ki18nc("@item:inlistbox Color name", "Transparent"), Qt::transparent));
     }
     KSelectAction *aColorPicker = new KSelectAction(QIcon(), aText, q);
     aColorPicker->setToolBarMode(KSelectAction::MenuMode);
     for (const auto &colorNameValue : colorList) {
         QColor color(colorNameValue.second);
-        QAction *aColor = new QAction(colorIcon(color), i18nc("@item:inlistbox Color name", "%1", colorNameValue.first), q);
+        QAction *aColor = new QAction(GuiUtils::createColorIcon({color}, QIcon(), GuiUtils::VisualizeTransparent), colorNameValue.first.toString(), q);
         aColorPicker->addAction(aColor);
         QObject::connect(aColor, &QAction::triggered, q, [this, colorType, color]() { slotSetColor(colorType, color); });
     }
@@ -415,53 +410,6 @@ const QIcon AnnotationActionHandlerPrivate::widthIcon(double width)
     return QIcon(pm);
 }
 
-const QIcon AnnotationActionHandlerPrivate::colorPickerIcon(const QString &iconName, const QColor &color)
-{
-    QIcon icon = QIcon::fromTheme(iconName);
-    if (!color.isValid()) {
-        return icon;
-    }
-    QSize iconSize = QSize(32, 32);
-    QPixmap pm = icon.pixmap(iconSize);
-    QPainter p(&pm);
-    p.fillRect(0, iconSize.height() - 8, iconSize.width(), 8, color);
-    p.end();
-    return QIcon(pm);
-}
-
-const QIcon AnnotationActionHandlerPrivate::colorIcon(const QColor &color)
-{
-    QSize iconSize = QSize(32, 32);
-    QPixmap pm(iconSize);
-    QPainter p(&pm);
-    if (color == Qt::transparent) {
-        p.fillRect(0, 0, iconSize.width(), iconSize.height(), Qt::white);
-        p.setPen(QPen(Qt::red, 2));
-        p.drawLine(iconSize.width() - 1, 0, 0, iconSize.height() - 1);
-    } else {
-        p.fillRect(0, 0, iconSize.width(), iconSize.height(), color);
-    }
-    p.setPen(Qt::black);
-    p.drawRect(0, 0, iconSize.width() - 1, iconSize.height() - 1);
-    p.end();
-    return QIcon(pm);
-}
-
-const QIcon AnnotationActionHandlerPrivate::opacityIcon(double opacity)
-{
-    QPixmap pm(32, 32);
-    pm.fill(Qt::transparent);
-    QPainter p(&pm);
-    p.setRenderHint(QPainter::Antialiasing);
-    p.setPen(Qt::NoPen);
-    QColor color(Qt::black);
-    color.setAlpha(opacity * 255 / 100);
-    p.setBrush(QBrush(color));
-    p.drawRect(4, 4, 24, 24);
-    p.end();
-    return QIcon(pm);
-}
-
 const QIcon AnnotationActionHandlerPrivate::stampIcon(const QString &stampIconName)
 {
     QPixmap stampPix = GuiUtils::loadStamp(stampIconName, 32);
@@ -471,11 +419,11 @@ const QIcon AnnotationActionHandlerPrivate::stampIcon(const QString &stampIconNa
         return QIcon::fromTheme(QStringLiteral("tag"));
 }
 
-void AnnotationActionHandlerPrivate::selectTool(int toolID)
+void AnnotationActionHandlerPrivate::selectTool(int toolId)
 {
-    selectedTool = toolID;
-    annotator->selectTool(toolID);
-    parseTool(toolID);
+    selectedTool = toolId;
+    annotator->selectTool(toolId);
+    parseTool(toolId);
 }
 
 void AnnotationActionHandlerPrivate::slotStampToolSelected(const QString &stamp)
@@ -485,17 +433,17 @@ void AnnotationActionHandlerPrivate::slotStampToolSelected(const QString &stamp)
     annotator->selectStampTool(stamp); // triggers a reparsing thus calling parseTool
 }
 
-void AnnotationActionHandlerPrivate::slotQuickToolSelected(int favToolID)
+void AnnotationActionHandlerPrivate::slotQuickToolSelected(int favToolId)
 {
-    int toolID = annotator->setQuickTool(favToolID); // always triggers an unuseful reparsing
-    if (toolID == -1) {
-        qWarning("Corrupted configuration for quick annotation tool with id: %d", favToolID);
+    int toolId = annotator->setQuickTool(favToolId); // always triggers an unuseful reparsing
+    if (toolId == -1) {
+        qWarning("Corrupted configuration for quick annotation tool with id: %d", favToolId);
         return;
     }
-    int indexOfActionInGroup = toolID - 1;
-    if (toolID == PageViewAnnotator::STAMP_TOOL_ID) {
+    int indexOfActionInGroup = toolId - 1;
+    if (toolId == PageViewAnnotator::STAMP_TOOL_ID) {
         // if the quick tool is a stamp we need to find its corresponding built-in tool action and select it
-        QDomElement favToolElement = annotator->quickTool(favToolID);
+        QDomElement favToolElement = annotator->quickTool(favToolId);
         QDomElement engineElement = favToolElement.firstChildElement(QStringLiteral("engine"));
         QDomElement annotationElement = engineElement.firstChildElement(QStringLiteral("annotation"));
         QString stampIconName = annotationElement.attribute(QStringLiteral("icon"));
@@ -515,7 +463,7 @@ void AnnotationActionHandlerPrivate::slotQuickToolSelected(int favToolID)
         //                          when new tool if different from the selected one
         favToolAction->trigger();
     } else {
-        selectTool(toolID);
+        selectTool(toolId);
     }
     aShowToolBar->setChecked(true);
 }
@@ -609,12 +557,10 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     d->agTools->addAction(aEllipse);
     d->agTools->addAction(aPolygon);
 
-    d->textQuickTools = new QList<QAction *>();
-    d->textTools = new QList<QAction *>();
-    d->textTools->append(aHighlighter);
-    d->textTools->append(aUnderline);
-    d->textTools->append(aSquiggle);
-    d->textTools->append(aStrikeout);
+    d->textTools.append(aHighlighter);
+    d->textTools.append(aUnderline);
+    d->textTools.append(aSquiggle);
+    d->textTools.append(aStrikeout);
 
     int toolId = 1;
     const QList<QAction *> tools = d->agTools->actions();
@@ -683,10 +629,10 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     // Opacity list
     d->aOpacity = new KSelectAction(QIcon::fromTheme(QStringLiteral("edit-opacity")), i18nc("@action:intoolbar Current annotation config option", "Opacity"), this);
     d->aOpacity->setToolBarMode(KSelectAction::MenuMode);
-    for (auto opacity : d->opacityStandardValues) {
-        KToggleAction *ann = new KToggleAction(d->opacityIcon(opacity), QStringLiteral("%1\%").arg(opacity), this);
+    for (double opacity : d->opacityStandardValues) {
+        KToggleAction *ann = new KToggleAction(GuiUtils::createOpacityIcon(opacity), QStringLiteral("%1\%").arg(opacity * 100), this);
         d->aOpacity->addAction(ann);
-        connect(ann, &QAction::triggered, this, [this, opacity]() { d->annotator->setAnnotationOpacity(opacity / 100); });
+        connect(ann, &QAction::triggered, this, [this, opacity]() { d->annotator->setAnnotationOpacity(opacity); });
     }
 
     connect(d->aAddToQuickTools, &QAction::triggered, d->annotator, &PageViewAnnotator::addToQuickAnnotations);
@@ -776,9 +722,13 @@ void AnnotationActionHandler::setupAnnotationToolBarVisibilityAction()
     connect(d->aShowToolBar, &QAction::toggled, this, [this](bool checked) { d->slotToolBarVisibilityChanged(checked); });
 }
 
-void AnnotationActionHandler::reparseTools()
+void AnnotationActionHandler::reparseBuiltinToolsConfig()
 {
     d->parseTool(d->selectedTool);
+}
+
+void AnnotationActionHandler::reparseQuickToolsConfig()
+{
     d->populateQuickAnnotations();
 }
 
@@ -797,10 +747,10 @@ void AnnotationActionHandler::setToolsEnabled(bool on)
 void AnnotationActionHandler::setTextToolsEnabled(bool on)
 {
     d->textToolsEnabled = on;
-    for (QAction *ann : qAsConst(*d->textTools)) {
+    for (QAction *ann : qAsConst(d->textTools)) {
         ann->setEnabled(on);
     }
-    for (QAction *ann : qAsConst(*d->textQuickTools)) {
+    for (QAction *ann : qAsConst(d->textQuickTools)) {
         ann->setEnabled(on);
     }
 }
