@@ -25,8 +25,6 @@
 #include <math.h>
 
 // local includes
-#include "core/annotations.h"
-#include "core/area.h"
 #include "core/observer.h"
 #include "core/page.h"
 #include "core/page_p.h"
@@ -37,7 +35,7 @@
 #include "settings_core.h"
 #include "ui/debug_ui.h"
 
-Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (KIconLoader::global()->loadIcon(QLatin1String("okular"), KIconLoader::NoGroup, IconSize(KIconLoader::Desktop), KIconLoader::DefaultState, QStringList(), 0, true)))
+Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (KIconLoader::global()->loadIcon(QLatin1String("okular"), KIconLoader::NoGroup, KIconLoader::SizeLarge, KIconLoader::DefaultState, QStringList(), nullptr, true)))
 
 #define TEXTANNOTATION_ICONSIZE 24
 
@@ -533,10 +531,11 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
                 acolor = Qt::yellow;
             acolor.setAlpha(opacity);
 
-            // get annotation boundary and drawn rect
+            // Annotation boundary in destPainter coordinates:
             QRect annotBoundary = a->transformedBoundingRectangle().geometry(scaledWidth, scaledHeight).translated(-scaledCrop.topLeft());
             QRect annotRect = annotBoundary.intersected(limits);
-            QRect innerRect(annotRect.left() - annotBoundary.left(), annotRect.top() - annotBoundary.top(), annotRect.width(), annotRect.height());
+            // Visible portion of the annotation at annotBoundary size:
+            QRect innerRect = annotRect.translated(-annotBoundary.topLeft());
             QRectF dInnerRect(innerRect.x() * dpr, innerRect.y() * dpr, innerRect.width() * dpr, innerRect.height() * dpr);
 
             Okular::Annotation::SubType type = a->subType();
@@ -596,22 +595,17 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
                 Okular::StampAnnotation *stamp = (Okular::StampAnnotation *)a;
 
                 // get pixmap and alpha blend it if needed
-                QPixmap pixmap = GuiUtils::loadStamp(stamp->stampIconName(), annotBoundary.width());
+                QPixmap pixmap = GuiUtils::loadStamp(stamp->stampIconName(), qMax(annotBoundary.width(), annotBoundary.height()) * dpr);
                 if (!pixmap.isNull()) // should never happen but can happen on huge sizes
                 {
-                    const QRect dInnerRect(QRectF(innerRect.x() * dpr, innerRect.y() * dpr, innerRect.width() * dpr, innerRect.height() * dpr).toAlignedRect());
-
-                    QPixmap scaledCroppedPixmap = pixmap.scaled(annotBoundary.width() * dpr, annotBoundary.height() * dpr).copy(dInnerRect);
+                    QPixmap scaledCroppedPixmap = pixmap.scaled(annotBoundary.width() * dpr, annotBoundary.height() * dpr).copy(dInnerRect.toAlignedRect());
                     scaledCroppedPixmap.setDevicePixelRatio(dpr);
 
-                    QImage scaledCroppedImage = scaledCroppedPixmap.toImage();
-
-                    if (opacity < 255)
-                        changeImageAlpha(scaledCroppedImage, opacity);
-                    pixmap = QPixmap::fromImage(scaledCroppedImage);
-
-                    // draw the scaled and al
-                    mixedPainter->drawPixmap(annotRect.topLeft(), pixmap);
+                    // Draw pixmap with opacity:
+                    mixedPainter->save();
+                    mixedPainter->setOpacity(mixedPainter->opacity() * opacity / 255.0);
+                    mixedPainter->drawPixmap(annotRect.topLeft(), scaledCroppedPixmap);
+                    mixedPainter->restore();
                 }
             }
             // draw GeomAnnotation
@@ -698,27 +692,6 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
     delete unbufferedAnnotations;
 }
 
-/** Private Helpers :: Pixmap conversion **/
-void PagePainter::cropPixmapOnImage(QImage &dest, const QPixmap *src, const QRect r)
-{
-    qreal dpr = src->devicePixelRatioF();
-
-    // handle quickly the case in which the whole pixmap has to be converted
-    if (r == QRect(0, 0, src->width() / dpr, src->height() / dpr)) {
-        dest = src->toImage();
-        dest = dest.convertToFormat(QImage::Format_ARGB32_Premultiplied);
-    }
-    // else copy a portion of the src to an internal pixmap (smaller) and convert it
-    else {
-        QImage croppedImage(r.width() * dpr, r.height() * dpr, QImage::Format_ARGB32_Premultiplied);
-        croppedImage.setDevicePixelRatio(dpr);
-        QPainter p(&croppedImage);
-        p.drawPixmap(0, 0, *src, r.left(), r.top(), r.width(), r.height());
-        p.end();
-        dest = croppedImage;
-    }
-}
-
 void PagePainter::recolor(QImage *image, const QColor &foreground, const QColor &background)
 {
     if (image->format() != QImage::Format_ARGB32_Premultiplied) {
@@ -960,34 +933,6 @@ void PagePainter::hueShiftNegative(QImage *image)
     }
 }
 
-/** Private Helpers :: Image Drawing **/
-// from Arthur - qt4
-static inline int qt_div_255(int x)
-{
-    return (x + (x >> 8) + 0x80) >> 8;
-}
-
-void PagePainter::changeImageAlpha(QImage &image, unsigned int destAlpha)
-{
-    image = image.convertToFormat(QImage::Format_ARGB32);
-    // iterate over all pixels changing the alpha component value
-    unsigned int *data = reinterpret_cast<unsigned int *>(image.bits());
-    unsigned int pixels = image.width() * image.height();
-
-    int source, sourceAlpha;
-    for (unsigned int i = 0; i < pixels; ++i) { // optimize this loop keeping byte order into account
-        source = data[i];
-        if ((sourceAlpha = qAlpha(source)) == 255) {
-            // use destAlpha
-            data[i] = qRgba(qRed(source), qGreen(source), qBlue(source), destAlpha);
-        } else {
-            // use destAlpha * sourceAlpha product
-            sourceAlpha = qt_div_255(destAlpha * sourceAlpha);
-            data[i] = qRgba(qRed(source), qGreen(source), qBlue(source), sourceAlpha);
-        }
-    }
-}
-
 void PagePainter::drawShapeOnImage(QImage &image, const NormalizedPath &normPath, bool closeShape, const QPen &pen, const QBrush &brush, double penWidthMultiplier, RasterOperation op
                                    // float antiAliasRadius
 )
@@ -997,10 +942,9 @@ void PagePainter::drawShapeOnImage(QImage &image, const NormalizedPath &normPath
     if (pointsNumber < 2)
         return;
 
-    int imageWidth = image.width();
-    int imageHeight = image.height();
-    double fImageWidth = (double)imageWidth;
-    double fImageHeight = (double)imageHeight;
+    const double dpr = image.devicePixelRatio();
+    const double fImageWidth = image.width() / dpr;
+    const double fImageHeight = image.height() / dpr;
 
     // stroke outline
     double penWidth = (double)pen.width() * penWidthMultiplier;
@@ -1043,8 +987,9 @@ void PagePainter::drawShapeOnImage(QImage &image, const NormalizedPath &normPath
 
 void PagePainter::drawEllipseOnImage(QImage &image, const NormalizedPath &rect, const QPen &pen, const QBrush &brush, double penWidthMultiplier, RasterOperation op)
 {
-    const double fImageWidth = (double)image.width();
-    const double fImageHeight = (double)image.height();
+    const double dpr = image.devicePixelRatio();
+    const double fImageWidth = image.width() / dpr;
+    const double fImageHeight = image.height() / dpr;
 
     // stroke outline
     const double penWidth = (double)pen.width() * penWidthMultiplier;
